@@ -33,21 +33,21 @@ import frozendict  # noqa: F401
 from snaptrade_client import schemas  # noqa: F401
 
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
-from snaptrade_client.model.action_strict import ActionStrict as ActionStrictSchema
-from snaptrade_client.model.units_nullable import UnitsNullable as UnitsNullableSchema
 from snaptrade_client.model.notional_value_nullable import NotionalValueNullable as NotionalValueNullableSchema
+from snaptrade_client.model.universal_symbol_id_nullable import UniversalSymbolIDNullable as UniversalSymbolIDNullableSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
-from snaptrade_client.model.manual_trade_form import ManualTradeForm as ManualTradeFormSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
+from snaptrade_client.model.action_strict_with_options import ActionStrictWithOptions as ActionStrictWithOptionsSchema
 from snaptrade_client.model.time_in_force_strict import TimeInForceStrict as TimeInForceStrictSchema
+from snaptrade_client.model.manual_trade_form_with_options import ManualTradeFormWithOptions as ManualTradeFormWithOptionsSchema
 from snaptrade_client.model.order_type_strict import OrderTypeStrict as OrderTypeStrictSchema
 
 from snaptrade_client.type.notional_value_nullable import NotionalValueNullable
-from snaptrade_client.type.units_nullable import UnitsNullable
-from snaptrade_client.type.manual_trade_form import ManualTradeForm
+from snaptrade_client.type.manual_trade_form_with_options import ManualTradeFormWithOptions
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
-from snaptrade_client.type.action_strict import ActionStrict
 from snaptrade_client.type.time_in_force_strict import TimeInForceStrict
+from snaptrade_client.type.universal_symbol_id_nullable import UniversalSymbolIDNullable
+from snaptrade_client.type.action_strict_with_options import ActionStrictWithOptions
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
 from snaptrade_client.type.account_order_record import AccountOrderRecord
 from snaptrade_client.type.order_type_strict import OrderTypeStrict
@@ -91,10 +91,10 @@ request_query_user_secret = api_client.QueryParameter(
     explode=True,
 )
 # body param
-SchemaForRequestBodyApplicationJson = ManualTradeFormSchema
+SchemaForRequestBodyApplicationJson = ManualTradeFormWithOptionsSchema
 
 
-request_body_manual_trade_form = api_client.RequestBody(
+request_body_manual_trade_form_with_options = api_client.RequestBody(
     content={
         'application/json': api_client.MediaType(
             schema=SchemaForRequestBodyApplicationJson),
@@ -200,17 +200,18 @@ class BaseApi(api_client.Api):
 
     def _place_force_order_mapped_args(
         self,
-        body: typing.Optional[ManualTradeForm] = None,
+        body: typing.Optional[ManualTradeFormWithOptions] = None,
         account_id: typing.Optional[str] = None,
-        action: typing.Optional[ActionStrict] = None,
-        universal_symbol_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrictWithOptions] = None,
         order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        universal_symbol_id: typing.Optional[UniversalSymbolIDNullable] = None,
+        symbol: typing.Optional[typing.Optional[str]] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
-        units: typing.Optional[UnitsNullable] = None,
+        units: typing.Optional[float] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
@@ -223,6 +224,8 @@ class BaseApi(api_client.Api):
             _body["action"] = action
         if universal_symbol_id is not None:
             _body["universal_symbol_id"] = universal_symbol_id
+        if symbol is not None:
+            _body["symbol"] = symbol
         if order_type is not None:
             _body["order_type"] = order_type
         if time_in_force is not None:
@@ -303,7 +306,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             headers=_headers,
         )
-        serialized_data = request_body_manual_trade_form.serialize(body, content_type)
+        serialized_data = request_body_manual_trade_form_with_options.serialize(body, content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
@@ -434,7 +437,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             headers=_headers,
         )
-        serialized_data = request_body_manual_trade_form.serialize(body, content_type)
+        serialized_data = request_body_manual_trade_form_with_options.serialize(body, content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
@@ -481,17 +484,18 @@ class PlaceForceOrder(BaseApi):
 
     async def aplace_force_order(
         self,
-        body: typing.Optional[ManualTradeForm] = None,
+        body: typing.Optional[ManualTradeFormWithOptions] = None,
         account_id: typing.Optional[str] = None,
-        action: typing.Optional[ActionStrict] = None,
-        universal_symbol_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrictWithOptions] = None,
         order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        universal_symbol_id: typing.Optional[UniversalSymbolIDNullable] = None,
+        symbol: typing.Optional[typing.Optional[str]] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
-        units: typing.Optional[UnitsNullable] = None,
+        units: typing.Optional[float] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
         **kwargs,
@@ -505,11 +509,12 @@ class PlaceForceOrder(BaseApi):
             query_params=query_params,
             account_id=account_id,
             action=action,
-            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
             time_in_force=time_in_force,
             user_id=user_id,
             user_secret=user_secret,
+            universal_symbol_id=universal_symbol_id,
+            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
@@ -523,17 +528,18 @@ class PlaceForceOrder(BaseApi):
     
     def place_force_order(
         self,
-        body: typing.Optional[ManualTradeForm] = None,
+        body: typing.Optional[ManualTradeFormWithOptions] = None,
         account_id: typing.Optional[str] = None,
-        action: typing.Optional[ActionStrict] = None,
-        universal_symbol_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrictWithOptions] = None,
         order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        universal_symbol_id: typing.Optional[UniversalSymbolIDNullable] = None,
+        symbol: typing.Optional[typing.Optional[str]] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
-        units: typing.Optional[UnitsNullable] = None,
+        units: typing.Optional[float] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -546,11 +552,12 @@ class PlaceForceOrder(BaseApi):
             query_params=query_params,
             account_id=account_id,
             action=action,
-            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
             time_in_force=time_in_force,
             user_id=user_id,
             user_secret=user_secret,
+            universal_symbol_id=universal_symbol_id,
+            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
@@ -566,17 +573,18 @@ class ApiForpost(BaseApi):
 
     async def apost(
         self,
-        body: typing.Optional[ManualTradeForm] = None,
+        body: typing.Optional[ManualTradeFormWithOptions] = None,
         account_id: typing.Optional[str] = None,
-        action: typing.Optional[ActionStrict] = None,
-        universal_symbol_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrictWithOptions] = None,
         order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        universal_symbol_id: typing.Optional[UniversalSymbolIDNullable] = None,
+        symbol: typing.Optional[typing.Optional[str]] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
-        units: typing.Optional[UnitsNullable] = None,
+        units: typing.Optional[float] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
         **kwargs,
@@ -590,11 +598,12 @@ class ApiForpost(BaseApi):
             query_params=query_params,
             account_id=account_id,
             action=action,
-            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
             time_in_force=time_in_force,
             user_id=user_id,
             user_secret=user_secret,
+            universal_symbol_id=universal_symbol_id,
+            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
@@ -608,17 +617,18 @@ class ApiForpost(BaseApi):
     
     def post(
         self,
-        body: typing.Optional[ManualTradeForm] = None,
+        body: typing.Optional[ManualTradeFormWithOptions] = None,
         account_id: typing.Optional[str] = None,
-        action: typing.Optional[ActionStrict] = None,
-        universal_symbol_id: typing.Optional[str] = None,
+        action: typing.Optional[ActionStrictWithOptions] = None,
         order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        universal_symbol_id: typing.Optional[UniversalSymbolIDNullable] = None,
+        symbol: typing.Optional[typing.Optional[str]] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
-        units: typing.Optional[UnitsNullable] = None,
+        units: typing.Optional[float] = None,
         notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -631,11 +641,12 @@ class ApiForpost(BaseApi):
             query_params=query_params,
             account_id=account_id,
             action=action,
-            universal_symbol_id=universal_symbol_id,
             order_type=order_type,
             time_in_force=time_in_force,
             user_id=user_id,
             user_secret=user_secret,
+            universal_symbol_id=universal_symbol_id,
+            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
